package App::Greple::under::mise;
use strict;
use warnings;

use App::Greple::under ':all';

1;

__DATA__

option default \
    -Munder \
    --under-custom-colormap
